#
# spec file for package libcloudproviders
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _typelibdir %(pkg-config --variable=typelibdir gobject-introspection-1.0)
%define _girdir %(pkg-config --variable=girdir gobject-introspection-1.0)
Name:           libcloudproviders
Version:        0.3.6
Release:        1.2
Summary:        Library/Client to integrate cloud storage providers
License:        LGPL-3.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/World/libcloudproviders
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.42.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.51.2
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.51.2
BuildRequires:  pkgconfig(glib-2.0) >= 2.51.2
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vapigen)

%description
Cross desktop library for desktop integration of cloud storage
providers and sync tools.

%package -n libcloudproviders0
Summary:        Library to integrate cloud storage providers
Group:          System/Libraries

%description -n libcloudproviders0
Cross desktop library for desktop integration of cloud storage
providers and sync tools.

%package -n     typelib-1_0-CloudProviders-0_3_0
Summary:        CloudProviders Introspection bindings
Group:          Development/Libraries/GNOME

%description -n typelib-1_0-CloudProviders-0_3_0
Cross desktop library for desktop integration of cloud storage
providers and sync tools.

This package provides the GObject Introspection bindings for cloudproviders.

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/C and C++
Requires:       libcloudproviders0 = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1

%build
%meson \
    -Denable-gtk-doc=true
%meson_build

%install
%meson_install

%check
%meson_test

%post -n libcloudproviders0 -p /sbin/ldconfig
%postun -n libcloudproviders0 -p /sbin/ldconfig

%files -n libcloudproviders0
%license LICENSE
%doc CHANGELOG README.md
%{_libdir}/libcloudproviders.so.*

%files -n typelib-1_0-CloudProviders-0_3_0
%{_typelibdir}/*.typelib

%files devel
%{_datadir}/gtk-doc/html/%{name}/
%{_includedir}/cloudproviders/
%{_libdir}/libcloudproviders.so
%{_libdir}/pkgconfig/cloudproviders.pc
%{_libdir}/*.so
%{_girdir}/*.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.deps
%{_datadir}/vala/vapi/*.vapi

%changelog
* Wed Mar 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.3.6:
  + Plug several memory leaks.
  + Avoid use-after-free within the Proxy.
  + Renamespace CloudProvidersProvider.
  + Reduce a bit the CloudProvidersAccount memory footprint.
* Thu Nov  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.5:
  + Avoid use after free with g_bus_get
* Wed Sep  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.4:
  + Re-release due to release tarball issue
- Changes from version 0.3.3:
  + Use a new way to register providers using .desktop files
- Drop libcloudproviders-rpmlintrc file/source: No longer needed.
* Wed Aug  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.2:
  + No upstream changes provided.
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Tue Dec 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add baselibs.conf: gtk4 for one depends on this.
  + Create libcloudproviders0-32bit.
* Tue Jun  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.3.1:
  + introspection: Limit namespace version to two digits
  + Fix compiler warning
  + Fix error handling on bus acquisition
  + Fix some warnings with the documentation and the introspection
  + Make meson throws error when vapigen option is active but
    program is not found
  + Update README.md.
  + build: Bypass generation of Vala vapi if vapigen executable
    can't be found.
- Update URL and Source to new location.
* Tue Sep  3 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.3.0:
  + Provide Vala bindings
  + Fix dbus server path
  + Use option for includedir
  + Fix crash when using more than one file chooser
  + Fix licensing
- Add GObject Introspection and Vala binding
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Dec 28 2017 luc14n0@linuxmail.org
- Update to version 0.2.5:
  + Fix leftovers of the daemon service breaking the build.
- Changes from version 0.2.4:
  + Remove libcloudproviders.service since a daemon won't be used
    anymore.
- Changes from version 0.2.3:
  + No news provided.
- Changes from version 0.2.2:
  + No news provided.
- Changes from version 0.2.1:
  + No news provided.
- Changes from version 0.2.0:
  + Use proper DBus.
  + Use proper class prefixes.
  + Remove daemon, since it's not necessary.
  + Remove manager, since it can be simplified.
- Update Url to https://gitlab.gnome.org/External/libcloudproviders
  since this is the current libcloudproviders' GitLab project page.
- Drop unneeded libcloudproviders Requires tag for the shared
  library package once the main package has been removed,
  following upstream's changes.
* Mon Sep  4 2017 dimstar@opensuse.org
- Initial package, version 0.1.1.
